@@ -1,7 +1,7 @@
 ##############################################################################
 # MDTraj: A Python Library for Loading, Saving, and Manipulating
 #         Molecular Dynamics Trajectories.
-# Copyright 2012-2014 Stanford University and the Authors
+# Copyright 2012-2022 Stanford University and the Authors
 #
 # Authors: Robert McGibbon
 # Contributors: Kyle A. Beauchamp, TJ Lane, Joshua Adelman, Lee-Ping Wang, Jason Swails
@@ -170,7 +170,7 @@ def _parse_topology(top, **kwargs):
         topology = top
     elif isinstance(top, Trajectory):
         topology = top.topology
-    elif isinstance(top, (string_types, os.PathLike)) and (ext in ['.pdb', '.pdb.gz', '.h5','.lh5']):
+    elif isinstance(top, (string_types, os.PathLike)) and (ext in ['.pdb', '.pdb.gz', '.pdbx', '.cif', '.h5','.lh5']):
         _traj = load_frame(top, 0, **kwargs)
         topology = _traj.topology
     elif isinstance(top, (string_types, os.PathLike)) and (ext in ['.prmtop', '.parm7', '.prm7']):
@@ -373,8 +373,8 @@ def load(filename_or_filenames, discard_overlapping_frames=False, **kwargs):
     #order to have an easier function later on
     if isinstance(filename_or_filenames, (string_types, os.PathLike)):
         filename_or_filenames = [filename_or_filenames]
-    
-    
+
+
     extensions = [_get_extension(f) for f in filename_or_filenames]
     extension = extensions[0]
     #Make the needed checks
@@ -416,7 +416,8 @@ def load(filename_or_filenames, discard_overlapping_frames=False, **kwargs):
         kwargs.pop('standard_names', None)
 
     trajectories = []
-    tmp_file = filename_or_filenames.pop(0)
+    tmp_file = filename_or_filenames[0]
+    filename_or_filenames = filename_or_filenames[1:]  # ignore first file
     try:
         # this is a little hack that makes calling load() more predictable. since
         # most of the loaders take a kwargs "top" except for load_hdf5, (since
@@ -427,7 +428,7 @@ def load(filename_or_filenames, discard_overlapping_frames=False, **kwargs):
         #TODO make all the loaders accept a pre parsed topology (top) in order to avoid
         #this part and have a more consistent interface and a faster load function
         t = loader(tmp_file, **kwargs)
-        
+
     except TypeError as e:
 
         #Don't want to intercept legit
@@ -468,7 +469,7 @@ def load(filename_or_filenames, discard_overlapping_frames=False, **kwargs):
         # Little monkey-patch to prevent further subsetting Topologies
         # this modified version of the topology will never exit this function
         kwargs['top'].subset = lambda atom_indices : subset_topology
-        
+
 
 
     # We know the topology is equal because we send the same topology
@@ -479,7 +480,7 @@ def load(filename_or_filenames, discard_overlapping_frames=False, **kwargs):
     # files to be read in without using ridiculous amounts of memory.
     for f in filename_or_filenames:
         t = loader(f, **kwargs)
-        
+
         t.topology = None
         trajectories.append(t)
 
@@ -966,8 +967,10 @@ class Trajectory(object):
         # combine with hashes of arrays
         hash_value ^= _hash_numpy_array(self._xyz)
         hash_value ^= _hash_numpy_array(self.time)
-        hash_value ^= _hash_numpy_array(self._unitcell_lengths)
-        hash_value ^= _hash_numpy_array(self._unitcell_angles)
+        if self._unitcell_lengths is not None:
+            hash_value ^= _hash_numpy_array(self._unitcell_lengths)
+        if self._unitcell_angles is not None:
+            hash_value ^= _hash_numpy_array(self._unitcell_angles)
         return hash_value
 
     def __eq__(self, other):
@@ -1269,8 +1272,8 @@ class Trajectory(object):
             for input to OpenMM
 
         """
-        from simtk.openmm import Vec3
-        from simtk.unit import nanometer
+        from openmm import Vec3
+        from openmm.unit import nanometer
 
         Pos = []
         for xyzi in self.xyz[frame]:
@@ -1297,8 +1300,8 @@ class Trajectory(object):
             The periodic box vectors for this frame, formatted for input to
             OpenMM.
         """
-        from simtk.openmm import Vec3
-        from simtk.unit import nanometer
+        from openmm import Vec3
+        from openmm.unit import nanometer
 
         vectors = self.unitcell_vectors[frame]
         if vectors is None:
