@@ -54,7 +54,7 @@ def load_restrt(filename, top=None, atom_indices=None):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         name of the AMBER restart file
     top : {str, Trajectory, Topology}
         Pass in either the path to a file containing topology information (e.g.,
@@ -94,7 +94,7 @@ class AmberRestartFile(object):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         The name of the file to open
     mode : {'r', 'w'}, default='r'
         The mode in which to open the file. Valid options are 'r' or 'w' for
@@ -410,9 +410,9 @@ def load_ncrestrt(filename, top=None, atom_indices=None):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         name of the AMBER restart file
-    top : {str, Trajectory, Topology}
+    top : {path-like, Trajectory, Topology}
         Pass in either the path to a file containing topology information (e.g.,
         a PDB, an AMBER prmtop, or certain types of Trajectory objects) to
         supply the necessary topology information that is not present in these
@@ -448,7 +448,7 @@ class AmberNetCDFRestartFile(object):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         The name of the file to open
     mode : {'r', 'w'}, default='r'
         The mode in which to open the file. Valid options are 'r' or 'w' for
